==> ReleaseV1.1.1.zip: winginterfacelibrary/src/DTO/Organization/OrganizationDTO.cs <==
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Organization
{
    /// <summary>
    /// 机构信息响应实体
    /// </summary>
    public class OrganizationDTO : OrganizationBasicDTO
    {
        /// <summary>
        /// 备注
        /// </summary>
        /// <value>机构描述</value>
        public string Description { get; set; }

        /// <summary>
        /// 顶级编码
        /// </summary>
        /// <value></value>
        public string RootCode { get; set; }

        /// <summary>
        /// 组织类型
        /// </summary>
        /// <value>0</value>
        public OrganizationTypeEnum OrganizationType { get; set; }

        /// <summary>
        /// 所属管理组列表
        /// </summary>
        /// <value>"",""</value>
        public List<string> AuthorityGroups { get; set; } = new List<string>();

        /// <summary>
        /// 经纬度
        /// </summary>
        /// <value>38.5</value>
        public string Nautica { get; set; }

        /// <summary>
        /// 审核状态
        /// </summary>
        /// <value>0</value>
        public OrganizationStateEnum State { get; set; }

        /// <summary>
        /// 机构负责人
        /// </summary>
        /// <value>"user001","user002"</value>
        public List<string> Directors { get; set; }

        /// <summary>
        /// 已分配的管理员列表
        /// </summary>
        /// <value>"admin001","admin002"</value>
        public List<string> AssignedAdmins { get; set; }

        /// <summary>
        /// 患者配置
        /// </summary>
        /// <value></value>
        public string PatientSettingJson { get; set; }

        /// <summary>
        /// 检查配置
        /// </summary>
        /// <value></value>
        public string ExamSettingJson { get; set; }

        /// <summary>
        /// 会诊配置
        /// </summary>
        /// <value></value>
        public string ConsultationSettingJson { get; set; }

        /// <summary>
        /// 患者配置版本
        /// </summary>
        /// <value></value>
        public string PatientSettingVersion { get; set; }

        /// <summary>
        /// 检查配置版本
        /// </summary>
        /// <value></value>
        public string ExamSettingVersion { get; set; }

        /// <summary>
        /// 会诊配置版本
        /// </summary>
        /// <value></value>
        public string ConsultationSettingVersion { get; set; }

        /// <summary>
        /// 父级名称
        /// </summary>
        /// <value>上级医院</value>
        public string ParentOrganizationName { get; set; }

        /// <summary>
        /// 是否开启CMS假数据
        /// </summary>
        /// <value></value>
        public bool CMSIsOpenFakeData { get; set; }

        /// <summary>
        /// CMS首页假数据模块列表
        /// </summary>
        public IList<StatisticDetailInfoDTO> CMSFakeData { get; set; }
    }

    /// <summary>
    /// CMS首页假数据模块对象
    /// </summary>
    public class StatisticDetailInfoDTO
    {
        /// <summary>
        /// 统计模块名称
        /// </summary>
        /// <value>MyPending</value>
        public string StatisticName { get; set; }

        /// <summary>
        /// CMS首页假数据模块Json
        /// </summary>
        /// <value>Json数据列表</value>
        public string StatisticJsonData { get; set; }
    }

    /// <summary>
    /// 组织机构基本信息
    /// </summary>
    public class OrganizationBaseDTO : BaseDTO
    {
        /// <summary>
        /// 组织编码
        /// </summary>
        /// <value>Test00001</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 组织名称
        /// </summary>
        /// <value>门诊部</value>
        public string OrganizationName { get; set; }
    }

    /// <summary>
    /// 组织机构基础信息
    /// </summary>
    public class OrganizationBasicDTO : OrganizationBaseDTO
    {
        /// <summary>
        /// 最精确地区编码
        /// </summary>
        /// <value>320500</value>
        public string RegionCode { get; set; }

        /// <summary>
        /// 父级编码
        /// </summary>
        /// <value>Test0000501_1</value>
        public string ParentCode { get; set; }

        /// <summary>
        /// logo图片地址
        /// </summary>
        /// <value>http://192.168.6.66:9001/Storage/B1154C6500E4F174249224B41284498E_7.PNG</value>
        public string LogoUrl { get; set; }

        /// <summary>
        /// 检查服务病人对象类型
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 是否是虚拟机构
        /// </summary>
        /// <value></value>
        public bool Isinvented { get; set; } = false;

        /// <summary>
        /// 配置列表
        /// </summary>
        /// <value></value>
        public List<SettingDTOClass> Settings { get; set; } = new List<SettingDTOClass>();

        /// <summary>
        /// AI应用集合
        /// </summary>
        public List<string> DiagnosisModules { get; set; } = new List<string>();

        /// <summary>
        /// 敏感信息加密显示
        /// </summary>
        /// <value>true</value>
        public bool IsEncryptedShow { get; set; } = true;

        /// <summary>
        /// 转诊超时时限
        /// </summary>
        public double ReferralLimitHours { get; set; } = 1;

        /// <summary>
        /// 可转诊机构
        /// </summary>
        public List<string> ReferralOrganizationCodes { get; set; } = new List<string>();

        /// <summary>
        /// 可转诊机构
        /// </summary>
        public List<ReferralOrganizationDTO> ReferralOrganizations { get; set; } = new List<ReferralOrganizationDTO>();
    }

    public class SettingDTOClass
    {
        /// <summary>
        /// 语言key
        /// </summary>
        /// <value>en-US</value>
        public string LangugeKey { get; set; }

        /// <summary>
        /// 配置模块
        /// </summary>
        /// <value>exam.json</value>
        public string SettingModule { get; set; }

        /// <summary>
        /// 自定义内容Json
        /// </summary>
        /// <value></value>
        public string CustomContent { get; set; }

        /// <summary>
        /// 完整内容（基础配置拼接自定义内容）
        /// </summary>
        /// <value></value>
        public string CompleteContent { get; set; }

        /// <summary>
        /// 基于哪个版本进行自定义的，对比用
        /// </summary>
        /// <value></value>
        public string BaseConfigVersion { get; set; }

        /// <summary>
        /// 语言版本
        /// </summary>
        /// <value></value>
        public string Version { get; set; }
    }

    public class ReferralOrganizationDTO
    {
        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 机构名称
        /// </summary>
        /// <value></value>
        public string OrganizationName { get; set; }
    }


    public class ConsultationBaseInfoItem
    {
        public string Name { get; set; }

        /// <summary>
        /// 是否基础设置，不可修改
        /// </summary>
        /// <value></value>
        public bool IsDefult { get; set; }

        public bool IsShow { get; set; }

        public bool Required { get; set; }

    }
}

==> ReleaseV1.1.2.zip: winginterfacelibrary/src/DTO/Organization/OrganizationDTO.cs <==
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Organization
{
    /// <summary>
    /// 机构信息响应实体
    /// </summary>
    public class OrganizationDTO : OrganizationBasicDTO
    {
        /// <summary>
        /// 备注
        /// </summary>
        /// <value>机构描述</value>
        public string Description { get; set; }

        /// <summary>
        /// 顶级编码
        /// </summary>
        /// <value></value>
        public string RootCode { get; set; }

        /// <summary>
        /// 组织类型
        /// </summary>
        /// <value>0</value>
        public OrganizationTypeEnum OrganizationType { get; set; }

        /// <summary>
        /// 所属管理组列表
        /// </summary>
        /// <value>"",""</value>
        public List<string> AuthorityGroups { get; set; } = new List<string>();

        /// <summary>
        /// 经纬度
        /// </summary>
        /// <value>38.5</value>
        public string Nautica { get; set; }

        /// <summary>
        /// 审核状态
        /// </summary>
        /// <value>0</value>
        public OrganizationStateEnum State { get; set; }

        /// <summary>
        /// 机构负责人
        /// </summary>
        /// <value>"user001","user002"</value>
        public List<string> Directors { get; set; }

        /// <summary>
        /// 已分配的管理员列表
        /// </summary>
        /// <value>"admin001","admin002"</value>
        public List<string> AssignedAdmins { get; set; }

        /// <summary>
        /// 患者配置
        /// </summary>
        /// <value></value>
        public string PatientSettingJson { get; set; }

        /// <summary>
        /// 检查配置
        /// </summary>
        /// <value></value>
        public string ExamSettingJson { get; set; }

        /// <summary>
        /// 会诊配置
        /// </summary>
        /// <value></value>
        public string ConsultationSettingJson { get; set; }

        /// <summary>
        /// 患者配置版本
        /// </summary>
        /// <value></value>
        public string PatientSettingVersion { get; set; }

        /// <summary>
        /// 检查配置版本
        /// </summary>
        /// <value></value>
        public string ExamSettingVersion { get; set; }

        /// <summary>
        /// 会诊配置版本
        /// </summary>
        /// <value></value>
        public string ConsultationSettingVersion { get; set; }

        /// <summary>
        /// 父级名称
        /// </summary>
        /// <value>上级医院</value>
        public string ParentOrganizationName { get; set; }
    }

    /// <summary>
    /// CMS首页假数据DTO
    /// </summary>
    public class StatisticDetailSettingDTO
    {
        /// <summary>
        /// cms模板列表
        /// </summary>
        /// <value></value>
        public string CMSTemplateCode { get; set; }
    }

    /// <summary>
    /// 组织机构基本信息
    /// </summary>
    public class OrganizationBaseDTO : BaseDTO
    {
        /// <summary>
        /// 组织编码
        /// </summary>
        /// <value>Test00001</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 组织名称
        /// </summary>
        /// <value>门诊部</value>
        public string OrganizationName { get; set; }
    }

    /// <summary>
    /// 组织机构基础信息
    /// </summary>
    public class OrganizationBasicDTO : OrganizationBaseDTO
    {
        /// <summary>
        /// 最精确地区编码
        /// </summary>
        /// <value>320500</value>
        public string RegionCode { get; set; }

        /// <summary>
        /// 父级编码
        /// </summary>
        /// <value>Test0000501_1</value>
        public string ParentCode { get; set; }

        /// <summary>
        /// logo图片地址
        /// </summary>
        /// <value>http://192.168.6.66:9001/Storage/B1154C6500E4F174249224B41284498E_7.PNG</value>
        public string LogoUrl { get; set; }

        /// <summary>
        /// 检查服务病人对象类型
        /// </summary>
        /// <value>0</value>
        public OrganizationPatientTypeEnum PatientType { get; set; }

        /// <summary>
        /// 是否是虚拟机构
        /// </summary>
        /// <value></value>
        public bool Isinvented { get; set; } = false;

        /// <summary>
        /// 配置列表
        /// </summary>
        /// <value></value>
        public List<SettingDTOClass> Settings { get; set; } = new List<SettingDTOClass>();

        /// <summary>
        /// AI应用集合
        /// </summary>
        public List<string> DiagnosisModules { get; set; } = new List<string>();

        /// <summary>
        /// 敏感信息加密显示
        /// </summary>
        /// <value>true</value>
        public bool IsEncryptedShow { get; set; } = true;

        /// <summary>
        /// 转诊超时时限
        /// </summary>
        public double ReferralLimitHours { get; set; } = 1;

        /// <summary>
        /// 可转诊机构
        /// </summary>
        public List<string> ReferralOrganizationCodes { get; set; } = new List<string>();

        /// <summary>
        /// 可转诊机构
        /// </summary>
        public List<ReferralOrganizationDTO> ReferralOrganizations { get; set; } = new List<ReferralOrganizationDTO>();

        /// <summary>
        /// 急诊医院编码
        /// </summary>
        /// <value></value>
        public string EmergencyOrganizationCode { get; set; }

        /// <summary>
        /// 急诊值班医生编码
        /// </summary>
        /// <value></value>
        public string EmergencyDoctorCode { get; set; }
    }

    public class SettingDTOClass
    {
        /// <summary>
        /// 语言key
        /// </summary>
        /// <value>en-US</value>
        public string LangugeKey { get; set; }

        /// <summary>
        /// 配置模块
        /// </summary>
        /// <value>exam.json</value>
        public string SettingModule { get; set; }

        /// <summary>
        /// 自定义内容Json
        /// </summary>
        /// <value></value>
        public string CustomContent { get; set; }

        /// <summary>
        /// 完整内容（基础配置拼接自定义内容）
        /// </summary>
        /// <value></value>
        public string CompleteContent { get; set; }

        /// <summary>
        /// 基于哪个版本进行自定义的，对比用
        /// </summary>
        /// <value></value>
        public string BaseConfigVersion { get; set; }

        /// <summary>
        /// 语言版本
        /// </summary>
        /// <value></value>
        public string Version { get; set; }
    }

    public class ReferralOrganizationDTO
    {
        /// <summary>
        /// 机构编码
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }
        /// <summary>
        /// 机构名称
        /// </summary>
        /// <value></value>
        public string OrganizationName { get; set; }
    }


    public class ConsultationBaseInfoItem
    {
        public string Name { get; set; }

        /// <summary>
        /// 是否基础设置，不可修改
        /// </summary>
        /// <value></value>
        public bool IsDefult { get; set; }

        public bool IsShow { get; set; }

        public bool Required { get; set; }

    }
}
